Crate workspacer_topo

Structs

TopologicalSortConfig
Configuration for how we do topological sorts. We remove Debug because closures cannot derive Debug easily.
TopologicalSortConfigBuilder
Builder for TopologicalSortConfig.

Enums

TopologicalSortConfigBuilderError
Error type for TopologicalSortConfigBuilder

Traits

BasicTopologicalSort
Trait for a simple, flat, topological ordering of all crates in the target.
FocusCrateTopologicalSort
Trait for focusing on a single crate/workspace: produce the subgraph of internal dependencies that lead up to the focus, then return either a flat or layered topological ordering.
LayeredTopologicalSort
Trait for returning a layered topological ordering of all crates in the target.
TopologicalSortInternalDeps
Trait specifically for a single CrateHandle. “topological_sort_internal_deps” => interpret self as the “focus crate”.

Functions

add_crate_and_deps
Minimal BFS-based function that adds crate_handle and all its internal dependencies (recursively) into graph, returning the node index of crate_handle in that graph.
create_workspace_and_get_handle
layered_subgraph_internal